<template>
  <el-dialog
    width="30%"
    top="5vh"
    title="提交补充信息"
    :visible.sync="innerVisible"
    append-to-body
    @close="$emit('update:currshowlist', false)"
    :show="currshowlist"
    class="weight-dialog"
  >
    <el-form
      :model="dataForm"
      :rules="dataRule"
      ref="dataForm"
      label-width="120px"
      class="l-mes"
    >
      <el-row>
        <el-col :span="24">
          <el-form-item label="包装尺寸" prop="packSize">
            <el-input
              v-model="dataForm.packSize"
              placeholder="包装尺寸"
            ></el-input>
          </el-form-item>
        </el-col>
      </el-row>
      <el-row>
        <el-col :span="24">
          <el-form-item label="包装重量" prop="packWeight">
            <el-input
              v-model="dataForm.packWeight"
              placeholder="包装重量"
            ></el-input>
          </el-form-item>
        </el-col>
      </el-row>
      <el-row>
        <el-col :span="24">
          <el-form-item label="包装材质" prop="packMaterial">
            <el-input
              v-model="dataForm.packMaterial"
              placeholder="包装材质"
            ></el-input>
          </el-form-item>
        </el-col>
      </el-row>
    </el-form>
    <div slot="footer" class="dialog-footer">
      <el-button @click="innerVisible = false">取 消</el-button>
      <el-button type="primary" :disabled="isSubmit" v-thinclick="`saveFeed`"
        >提 交</el-button
      >
    </div>
  </el-dialog>
</template>
<script>
import { addObj } from '@/api/zte/zxweightlabel'
export default {
  props: {
    currshowlist: {
      type: Boolean,
      default: false
    },
    formInfo: {
      type: Object,
      default: () => {
        return {}
      }
    }
  },
  data() {
    return {
      innerVisible: false,
      isSubmit: false,
      dataForm: {
        packSize: null,
        packMaterial: null,
        packWeight: null
      },
      dataRule: {}
    }
  },
  methods: {
    saveFeed() {
      this.isSubmit = true
      // 校验
      if (
        this.dataForm.packSize != null &&
        this.dataForm.packSize.trim() != ''
      ) {
        const packSizeArr = this.dataForm.packSize.split('*')
        if (packSizeArr.length == 3) {
          if (packSizeArr[0].trim() != '') {
            if (isNaN(Number(packSizeArr[0]))) {
              this.$message.error('包装尺寸长宽高必须为纯数字')
              this.isSubmit = false
              return
            }
          } else {
            this.$message.error('包装尺寸数字不能为空')
            this.isSubmit = false
            return
          }
          if (packSizeArr[1].trim() != '') {
            if (isNaN(Number(packSizeArr[1]))) {
              this.$message.error('包装尺寸长宽高必须为纯数字')
              this.isSubmit = false
              return
            }
          } else {
            this.$message.error('包装尺寸数字不能为空')
            this.isSubmit = false
            return
          }
          if (packSizeArr[2].trim() != '') {
            if (isNaN(Number(packSizeArr[2]))) {
              this.$message.error('包装尺寸长宽高必须为纯数字')
              this.isSubmit = false
              return
            }
          } else {
            this.$message.error('包装尺寸数字不能为空')
            this.isSubmit = false
            return
          }
        } else {
          this.$message.error('包装尺寸必须由两个*号分隔')
          this.isSubmit = false
          return
        }
      } else {
        this.$message.error('包装尺寸不能为空')
        this.isSubmit = false
        return
      }

      if (
        this.dataForm.packWeight != null &&
        this.dataForm.packWeight.trim() != ''
      ) {
        if (isNaN(Number(this.dataForm.packWeight))) {
          this.$message.error('包装重量必须为纯数字')
          this.isSubmit = false
          return
        }
      } else {
        this.$message.error('包装重量不能为空')
        this.isSubmit = false
        return
      }
      if (
        this.dataForm.packMaterial != null &&
        this.dataForm.packMaterial.trim() != ''
      ) {
      } else {
        this.$message.error('包装材质不能为空')
        this.isSubmit = false
        return
      }
      /* if (!this.checkDecimal(this.scanFeedList[i].suppliedQuantity)) {
          this.isSubmit = false
          this.$message.error(
            '第' + (i + 1) + '数据格式有误，数据大于0且最多保留6位小数'
          )
          return
        } */

      const weightObj = {
        pkgCode: this.formInfo.pkgNo.trim(),
        grossWeight: this.formInfo.grossWeight.trim(),
        packSize: this.dataForm.packSize.trim(),
        packMaterial: this.dataForm.packMaterial.trim(),
        packWeight: this.dataForm.packWeight.trim(),
        shopCode: 'GD'
      }
      addObj(weightObj)
        .then((response) => {
          const data = response.data
          if (data.code === 0) {
            this.$message.success('提交成功')
          }
          this.$emit('refreshWeightList')
          this.isSubmit = false
          this.innerVisible = false
        })
        .catch(() => {
          this.isSubmit = false
        })
    },
    // 大于0且最多保留6位小数
    checkDecimal(value) {
      const reg = /^(?!0+(?:\.0+)?$)(?:[1-9]\d*|0)(?:\.\d{1,6})?$/
      return reg.test(value)
    },
    initData() {
      this.dataForm.packSize = null
      this.dataForm.packMaterial = null
      this.dataForm.packWeight = null
    }
  },
  watch: {
    currshowlist() {
      this.innerVisible = this.currshowlist
      this.initData()
      if (this.currshowlist) {
        this.$nextTick(() => {})
      }
    }
  },
  mounted() {}
}
</script>
<style scoped>
.weight-dialog >>> .el-dialog__body {
  padding: 0px 20px 30px 20px;
}
</style>
